@@ -94,8 +94,8 @@ bool parseMaterial(Material &material, TiXmlElement *config, bool only_name_is_o
   if (!has_rgb && !has_filename) {
     if (!only_name_is_ok) // no need for an error if only name is ok
     {
-      //if (!has_rgb) logError(std::string("Material ["+material.name+"] color has no rgba").c_str());
-      //if (!has_filename) logError(std::string("Material ["+material.name+"] not defined in file").c_str());
+      // if (!has_rgb) logError(std::string("Material ["+material.name+"] color has no rgba").c_str());
+      // if (!has_filename) logError(std::string("Material ["+material.name+"] not defined in file").c_str());
     }
     return false;
   }
@@ -362,6 +362,10 @@ bool parseVisual(Visual &vis, TiXmlElement *config)
   if (!vis.geometry)
     return false;
 
+  const char *name_char = config->Attribute("name");
+  if (name_char)
+    vis.name = name_char;
+
   // Material
   TiXmlElement *mat = config->FirstChildElement("material");
   if (mat) {
@@ -376,19 +380,10 @@ bool parseVisual(Visual &vis, TiXmlElement *config)
     vis.material.reset(new Material());
     if (!parseMaterial(*vis.material, mat, true))
     {
-      //vis.material.reset();
-      //return false;
-      //logDebug("material has only name, actual material definition may be in the model");
+      //logDebug("urdfdom: material has only name, actual material definition may be in the model");
     }
   }
   
-  // Group Tag (optional)
-  // collision blocks without a group tag are designated to the "default" group
-  const char *group_name_char = config->Attribute("group");
-  if (!group_name_char)
-    vis.group_name = std::string("default");
-  else
-    vis.group_name = std::string(group_name_char);
   return true;
 }
 
@@ -409,13 +404,10 @@ bool parseCollision(Collision &col, TiXmlElement* config)
   if (!col.geometry)
     return false;
 
-  // Group Tag (optional)
-  // collision blocks without a group tag are designated to the "default" group
-  const char *group_name_char = config->Attribute("group");
-  if (!group_name_char)
-    col.group_name = std::string("default");
-  else
-    col.group_name = std::string(group_name_char);
+  const char *name_char = config->Attribute("name");
+  if (name_char)
+    col.name = name_char;
+
   return true;
 }
 
@@ -452,19 +444,7 @@ bool parseLink(Link &link, TiXmlElement* config)
     vis.reset(new Visual());
     if (parseVisual(*vis, vis_xml))
     {
-      boost::shared_ptr<std::vector<boost::shared_ptr<Visual > > > viss = link.getVisuals(vis->group_name);
-      if (!viss)
-      {
-        // group does not exist, create one and add to map
-        viss.reset(new std::vector<boost::shared_ptr<Visual > >);
-        // new group name, create vector, add vector to map and add Visual to the vector
-        link.visual_groups.insert(make_pair(vis->group_name,viss));
-        //logDebug("successfully added a new visual group name '%s'",vis->group_name.c_str());
-      }
-      
-      // group exists, add Visual to the vector in the map
-      viss->push_back(vis);
-      //logDebug("successfully added a new visual under group name '%s'",vis->group_name.c_str());
+      link.visual_array.push_back(vis);
     }
     else
     {
@@ -475,27 +455,10 @@ bool parseLink(Link &link, TiXmlElement* config)
   }
 
   // Visual (optional)
-  // Assign one single default visual pointer from the visual_groups map
-  link.visual.reset();
-  boost::shared_ptr<std::vector<boost::shared_ptr<Visual > > > default_visual = link.getVisuals("default");
-  if (!default_visual)
-  {
-    //("No 'default' visual group for Link '%s'", this->name.c_str());
-  }
-  else if (default_visual->empty())
-  {
-    //("'default' visual group is empty for Link '%s'", this->name.c_str());
-  }
-  else
-  {
-    if (default_visual->size() > 1)
-    {
-      //("'default' visual group has %d visuals for Link '%s', taking the first one as default",(int)default_visual->size(), this->name.c_str());
-    }
-    link.visual = (*default_visual->begin());
-  }
-
-
+  // Assign the first visual to the .visual ptr, if it exists
+  if (!link.visual_array.empty())
+    link.visual = link.visual_array[0];
+  
   // Multiple Collisions (optional)
   for (TiXmlElement* col_xml = config->FirstChildElement("collision"); col_xml; col_xml = col_xml->NextSiblingElement("collision"))
   {
@@ -503,20 +466,7 @@ bool parseLink(Link &link, TiXmlElement* config)
     col.reset(new Collision());
     if (parseCollision(*col, col_xml))
     {      
-      boost::shared_ptr<std::vector<boost::shared_ptr<Collision > > > cols = link.getCollisions(col->group_name);  
-      
-      if (!cols)
-      {
-        // group does not exist, create one and add to map
-        cols.reset(new std::vector<boost::shared_ptr<Collision > >);
-        // new group name, create vector, add vector to map and add Collision to the vector
-        link.collision_groups.insert(make_pair(col->group_name,cols));
-        //logDebug("successfully added a new collision group name '%s'",col->group_name.c_str());
-      }
-
-      // group exists, add Collision to the vector in the map
-      cols->push_back(col);
-      //logDebug("successfully added a new collision under group name '%s'",col->group_name.c_str());
+      link.collision_array.push_back(col);
     }
     else
     {
@@ -526,29 +476,12 @@ bool parseLink(Link &link, TiXmlElement* config)
     }
   }
   
-  // Collision (optional)
-  // Assign one single default collision pointer from the collision_groups map
-  link.collision.reset();
-  boost::shared_ptr<std::vector<boost::shared_ptr<Collision > > > default_collision = link.getCollisions("default");
+  // Collision (optional)  
+  // Assign the first collision to the .collision ptr, if it exists
+  if (!link.collision_array.empty())
+    link.collision = link.collision_array[0];
 
-  if (!default_collision)
-  {
-    //logDebug("No 'default' collision group for Link '%s'", link.name.c_str());
-  }
-  else if (default_collision->empty())
-  {
-    //logDebug("'default' collision group is empty for Link '%s'", link.name.c_str());
-  }
-  else
-  {
-    if (default_collision->size() > 1)
-    {
-      //logWarn("'default' collision group has %d collisions for Link '%s', taking the first one as default",(int)default_collision->size(), link.name.c_str());
-    }
-    link.collision = (*default_collision->begin());
-  }
-
-  return false;
+  return true;
 }
 
 /* exports */
@@ -689,9 +622,6 @@ bool exportVisual(Visual &vis, TiXmlElement *xml)
   if (vis.material)
     exportMaterial(*vis.material, visual_xml);
 
-  if (!vis.group_name.empty())
-    visual_xml->SetAttribute("group", vis.group_name);
-
   xml->LinkEndChild(visual_xml);
 
   return true;
@@ -712,9 +642,6 @@ bool exportCollision(Collision &col, TiXmlElement* xml)
 
   exportGeometry(col.geometry, collision_xml);
 
-  if (!col.group_name.empty())
-    collision_xml->SetAttribute("group", col.group_name);
-
   xml->LinkEndChild(collision_xml);
 
   return true;
@@ -725,9 +652,12 @@ bool exportLink(Link &link, TiXmlElement* xml)
   TiXmlElement * link_xml = new TiXmlElement("link");
   link_xml->SetAttribute("name", link.name);
 
-  exportInertial(*link.inertial, link_xml);
-  exportVisual(*link.visual, link_xml);
-  exportCollision(*link.collision, link_xml);
+  if (link.inertial)
+    exportInertial(*link.inertial, link_xml);
+  for (std::size_t i = 0 ; i < link.visual_array.size() ; ++i)
+    exportVisual(*link.visual_array[i], link_xml);
+  for (std::size_t i = 0 ; i < link.collision_array.size() ; ++i)
+    exportCollision(*link.collision_array[i], link_xml);
 
   xml->LinkEndChild(link_xml);
 
